@@ -21,3 +21,9 @@ def test_config():
     print(config("log_path"))
     print(config("log", "logging.level.com.apus"))
     print(config("channel_country_config"))
+
+def test_another_config():
+    init_config(setting_file_name='settings.another.ini')
+    print(config("property_a"))
+    init_config()
+    print(config("property_a"))
